@@ -514,7 +514,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id) REGEXP %s"""],
-                    params = [pattern])
+                    params = [pattern]).count()
             totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
@@ -523,7 +523,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id) REGEXP %s"""],
-                    params = [totPattern])
+                    params = [totPattern]).count()
             SPprob += float(count) / float(totCount)
             if i != len(phones)-1:
                 patt = [any_segment] * i
@@ -538,7 +538,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id) REGEXP %s"""],
-                    params = [pattern])
+                    params = [pattern]).count()
                 totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
@@ -547,7 +547,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id) REGEXP %s"""],
-                    params = [totPattern])
+                    params = [totPattern]).count()
                 BPprob += float(count) / float(totCount)
         SPprob = SPprob / float(len(phones))
         BPprob = BPprob / float(len(phones)-1)
