@@ -112,7 +112,7 @@ def doBasicAnalysis(form):
         #    AnalyzeSpeaker.delay(s,form)
         #job = group([AnalyzeSpeaker.s(speaker, form) for speaker in sp])
         #job.apply_async(link=consolidateResultFiles.s())
-        res = chord((AnalyzeSpeaker.s(s, form.cleaned_data) for s in sp), combineResults.s(wanted=form.get_wanted_fields()))()
+        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s(wanted=form.get_wanted_fields()))()
         res.get()
 
 @task()
